@@ -81,9 +81,9 @@ bool FFmpegEngine::play()
 
 bool FFmpegEngine::enqueue(InputSource *source)
 {
-    QStringList filters = m_factory->properties().filters;
+    const QStringList filters = m_factory->properties().filters;
     bool supports = false;
-    foreach(QString filter, filters)
+    for(const QString &filter : qAsConst(filters))
     {
         QRegExp regexp(filter, Qt::CaseInsensitive, QRegExp::Wildcard);
         if((supports = regexp.exactMatch(source->path())))
@@ -160,10 +160,10 @@ void FFmpegEngine::pause()
     }
 }
 
-void FFmpegEngine::setMuted(bool muted)
+/*void FFmpegEngine::setMuted(bool muted)
 {
     m_audioThread->setMuted(muted);
-}
+}*/
 
 void FFmpegEngine::onStopRequest()
 {
