@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -53,7 +53,7 @@ EngineProperties FFVideoFactory::properties() const
 
 bool FFVideoFactory::supports(const QString &source) const
 {
-    foreach(QString filter,  properties().filters)
+    for(const QString &filter : properties().filters)
     {
         QRegExp regexp(filter, Qt::CaseInsensitive, QRegExp::Wildcard);
         if (regexp.exactMatch(source))
@@ -71,7 +71,7 @@ QList<TrackInfo *> FFVideoFactory::createPlayList(const QString &path, TrackInfo
 {
     TrackInfo *info = new TrackInfo(path);
 
-    if(parts == TrackInfo::NoParts)
+    if(parts == TrackInfo::Parts())
         return QList<TrackInfo*>() << info;
 
     AVFormatContext *in = nullptr;
