@@ -68,11 +68,9 @@ DecoderFFap::DecoderFFap(const QString &path, QIODevice *i)
 {
     //m_data = 0;
     m_path = path;
-    m_ffap_decoder = nullptr;
     ffap_load();
 }
 
-
 DecoderFFap::~DecoderFFap()
 {
     deinit();
@@ -88,7 +86,7 @@ bool DecoderFFap::initialize()
         qWarning("DecoderFFap: unable to initialize decoder");
         return false;
     }
-    Qmmp::AudioFormat format = Qmmp::PCM_UNKNOWM;
+    Qmmp::AudioFormat format = Qmmp::PCM_UNKNOWN;
     switch(m_ffap_decoder->bps)
     {
     case 8:
