@@ -24,26 +24,14 @@
 #include <taglib/apefile.h>
 #include <taglib/apetag.h>
 #include <taglib/tfilestream.h>
-#include "cueparser.h"
+#include <qmmp/cueparser.h>
 #include "decoder_ffap.h"
 #include "decoder_ffapcue.h"
 
-
 DecoderFFapCUE::DecoderFFapCUE(const QString &url)
     : Decoder()
 {
-    m_path = url;
-    m_decoder = nullptr;
-    m_parser = nullptr;
-    m_track = 0;
-    m_buf = nullptr;
-    m_input = nullptr;
-    m_length = 0;
-    m_offset = 0;
-    m_totalBytes = 0;
-    m_buf_size = 0;
-    m_sz = 0;
-    length_in_bytes = 0;
+    m_url = url;
 }
 
 DecoderFFapCUE::~DecoderFFapCUE()
@@ -64,38 +52,37 @@ DecoderFFapCUE::~DecoderFFapCUE()
 
 bool DecoderFFapCUE::initialize()
 {
-    QString p = m_path;
-    if(!m_path.startsWith("ape://") || p.endsWith(".ape"))
+    QString filePath = m_url;
+    if(!m_url.startsWith("ape://") || filePath.endsWith(".ape"))
     {
         qWarning("DecoderFFapCUE: invalid url.");
         return false;
     }
-    p.remove("ape://");
-    p.remove(QRegExp("#\\d+$"));
+    filePath.remove("ape://");
+    filePath.remove(QRegExp("#\\d+$"));
+    m_track = m_url.section("#", -1).toInt();
 
-    TagLib::FileStream stream(QStringToFileName(p), true);
+    TagLib::FileStream stream(QStringToFileName(filePath), true);
     TagLib::APE::File file(&stream);
 
     TagLib::APE::Tag *tag = file.APETag();
 
-    if (tag && tag->itemListMap().contains("CUESHEET"))
+    if(!tag || !tag->itemListMap().contains("CUESHEET"))
     {
-        qDebug("DecoderFFapCUE: using cuesheet from ape tags");
-        m_parser = new CUEParser(tag->itemListMap()["CUESHEET"].toString().toCString(true), p);
-        m_track = m_path.section("#", -1).toInt();
-    }
-    else
-    {
-        qWarning("DecoderFLAC: unable to find cuesheet comment.");
+        qWarning("DecoderFFapCUE: unable to find cuesheet comment.");
         return false;
     }
 
-    if(m_track > m_parser->count() || m_parser->count() == 0)
+    m_parser = new CueParser(tag->itemListMap()["CUESHEET"].toString().toCString(true));
+    m_parser->setDuration(file.audioProperties()->lengthInMilliseconds());
+    m_parser->setUrl("ape", filePath);
+
+    if(m_track > m_parser->count() || m_parser->isEmpty())
     {
         qWarning("DecoderFFapCUE: invalid cuesheet");
         return false;
     }
-    m_input = new QFile(p);
+    m_input = new QFile(filePath);
     if(!m_input->open(QIODevice::ReadOnly))
     {
         qWarning("DecoderFFapCUE: %s", qPrintable(m_input->errorString()));
@@ -104,10 +91,10 @@ bool DecoderFFapCUE::initialize()
     QMap<Qmmp::MetaData, QString> metaData = m_parser->info(m_track)->metaData();
     addMetaData(metaData); //send metadata
 
-    m_length = m_parser->duration(m_track);
+    m_duration = m_parser->duration(m_track);
     m_offset = m_parser->offset(m_track);
 
-    m_decoder = new DecoderFFap(p, m_input);
+    m_decoder = new DecoderFFap(filePath, m_input);
     if(!m_decoder->initialize())
     {
         qWarning("DecoderFFapCUE: invalid audio file");
@@ -119,34 +106,34 @@ bool DecoderFFapCUE::initialize()
               m_decoder->audioParameters().channels(),
               m_decoder->audioParameters().format());
 
-    length_in_bytes = audioParameters().sampleRate() *
+    m_trackSize = audioParameters().sampleRate() *
             audioParameters().channels() *
-            audioParameters().sampleSize() * m_length/1000;
-    m_totalBytes = 0;
+            audioParameters().sampleSize() * m_duration / 1000;
+    m_written = 0;
 
-    m_sz = audioParameters().sampleSize() * audioParameters().channels();
+    m_frameSize = audioParameters().sampleSize() * audioParameters().channels();
 
-    setReplayGainInfo(m_parser->replayGain(m_track)); //send ReplayGaing info
+    setReplayGainInfo(m_parser->info(m_track)->replayGainInfo()); //send ReplayGaing info
     addMetaData(m_parser->info(m_track)->metaData()); //send metadata
     return true;
 }
 
 qint64 DecoderFFapCUE::totalTime() const
 {
-    return m_decoder ? m_length : 0;
+    return m_decoder ? m_duration : 0;
 }
 
 void DecoderFFapCUE::seek(qint64 pos)
 {
     m_decoder->seek(m_offset + pos);
-    m_totalBytes = audioParameters().sampleRate() *
+    m_written = audioParameters().sampleRate() *
             audioParameters().channels() *
             audioParameters().sampleSize() * pos/1000;
 }
 
 qint64 DecoderFFapCUE::read(unsigned char *data, qint64 size)
 {
-    if(length_in_bytes - m_totalBytes < m_sz) //end of cue track
+    if(m_trackSize - m_written < m_frameSize) //end of cue track
         return 0;
 
     qint64 len = 0;
@@ -170,15 +157,15 @@ qint64 DecoderFFapCUE::read(unsigned char *data, qint64 size)
     if(len <= 0) //end of file
         return 0;
 
-    if(len + m_totalBytes <= length_in_bytes)
+    if(len + m_written <= m_trackSize)
     {
-        m_totalBytes += len;
+        m_written += len;
         return len;
     }
 
-    qint64 len2 = qMax(qint64(0), length_in_bytes - m_totalBytes);
-    len2 = (len2 / m_sz) * m_sz; //whole of samples of each channel
-    m_totalBytes += len2;
+    qint64 len2 = qMax(qint64(0), m_trackSize - m_written);
+    len2 = (len2 / m_frameSize) * m_frameSize; //whole of samples of each channel
+    m_written += len2;
     //save data of the next track
     if(m_buf)
         delete[] m_buf;
@@ -196,7 +183,7 @@ int DecoderFFapCUE::bitrate() const
 const QString DecoderFFapCUE::nextURL() const
 {
     if(m_track +1 <= m_parser->count())
-        return m_parser->trackURL(m_track + 1);
+        return m_parser->url(m_track + 1);
     else
         return QString();
 }
@@ -206,13 +193,13 @@ void DecoderFFapCUE::next()
     if(m_track +1 <= m_parser->count())
     {
         m_track++;
-        m_length = m_parser->duration(m_track);
+        m_duration = m_parser->duration(m_track);
         m_offset = m_parser->offset(m_track);
-        length_in_bytes = audioParameters().sampleRate() *
+        m_trackSize = audioParameters().sampleRate() *
                 audioParameters().channels() *
-                audioParameters().sampleSize() * m_length/1000;
+                audioParameters().sampleSize() * m_duration/1000;
         addMetaData(m_parser->info(m_track)->metaData());
-        setReplayGainInfo(m_parser->replayGain(m_track));
-        m_totalBytes = 0;
+        setReplayGainInfo(m_parser->info(m_track)->replayGainInfo());
+        m_written = 0;
     }
 }
